@@ -182,7 +182,7 @@ class LibMarkdown(object):
         for i in argv:
             if len(i) != 0:
                 msg = i.replace('；',';')
-                msg = msg.replace('。',';')
+                #msg = msg.replace('。',';')
                 msg = '<br>'.join(msg.strip(';').split(';'))
                 data += str(msg) + "|"
             else:
