@@ -14,7 +14,7 @@ except ImportError:
     import libsvg
     import libmd
 
-__version__ = 'v1.3.4'
+__version__ = 'v1.3.6'
 
 class TranslateJson(object):
     def __init__(self, js_file, link_path, dir_type, output_md, output_gitbook, output_xmind, \
@@ -474,7 +474,8 @@ class TranslateJson(object):
             self.reg_rst += '   ' + name + '.md\n'
             with open(file_path, 'w') as fd:
                 fd.write(register_data)
-            self.reg_data += '{% include "./' + name +  '.md" %}\n'
+            #self.reg_data += '{% include "./' + name +  '.md" %}\n'
+            self.reg_data += register_data + '\n'
 
     def add_xmind_md(self, name, des):
         self.xmind_md += '* ' + name + '\n'
@@ -688,9 +689,9 @@ def usage():
 
     parameters:
         -f : 指定json文件
-        -d : 加-d ,保留-f所指路径层级, 不加-d 只保留-f所指的文件名
-        -g : 加-g ,生成gitbook目录, 不加-g 生成单个markdown文件
-        -l : 指定链接目录, 把生成的gitbook目录,放到指定目录下(加-l 默认加上了-g)
+        -l : 指定生成目录, 把生成的gitbook目录,放到指定目录下
+        -d : 加-d ,在生成目录中保留-f所指路径层级, 不加-d 只以json文件名创建目录
+        -g : 加-g ,生成gitbook目录, 不加-g 生成单个markdown文件(加-l 默认加上了-g)
     """
     print(usage.__doc__)
 
